<template>
  <el-dialog
    :title="!dataForm.id ? '新增' : '修改'"
    :close-on-click-modal="false"
    :visible.sync="visible"
    append-to-body
  >
    <el-form
      :model="dataForm"
      :rules="dataRule"
      ref="dataForm"
      @keyup.enter.native="dataFormSubmit()"
      label-width="80px"
      class="l-mes"
      :disabled="!editable"
    >
      <el-row>
        <el-col :span="12">
          <el-form-item label="报废单号" prop="scrapNo">
            <el-input
              v-model="dataForm.scrapNo"
              placeholder="报废单号"
              disabled
            ></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="零件" prop="partId">
            <el-input v-model="dataForm.partNo" placeholder="零件" disabled>
              <el-button
                slot="append"
                icon="el-icon-search"
                @click="openStockDialog()"
              ></el-button>
            </el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="零件批号" prop="partBatchNo">
            <el-input
              v-model="dataForm.partBatchNo"
              placeholder="零件批号"
              disabled
            ></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="零件序列号" prop="partSn">
            <el-input
              v-model="dataForm.partSn"
              placeholder="零件序列号"
              disabled
            ></el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="仓库" prop="warehouseId">
            <el-input
              v-model="dataForm.warehouseName"
              placeholder="仓库"
              disabled
            ></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="库位" prop="locationId">
            <el-input
              v-model="dataForm.locationName"
              placeholder="库位"
              disabled
            ></el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="库存数量" prop="locQty">
            <el-input
              v-model="dataForm.locQty"
              placeholder="库存数量"
              disabled
            ></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="报废数量" prop="scrapQty">
            <el-input
              v-model="dataForm.scrapQty"
              placeholder="报废数量"
            ></el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="报废人" prop="scrapUser">
            <el-input
              v-model="dataForm.scrapUser"
              placeholder="报废人"
              disabled
            ></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="系统编号" prop="systemNo">
            <el-input
              v-model="dataForm.systemNo"
              placeholder="系统编号"
              disabled
            ></el-input>
          </el-form-item>
        </el-col>
      </el-row>
    </el-form>
    <span slot="footer" class="dialog-footer">
      <el-button @click="visible = false">取消</el-button>
      <el-button type="primary" @click="dataFormSubmit()">确定</el-button>
    </span>
    <Stock
      :currshowlist.sync="showStock"
      ref="Stock"
      @listenToPartEvent="selectStock"
    />
  </el-dialog>
</template>

<script>
import Stock from '@/views/common/stock'
import { mapGetters } from 'vuex'
import {
  addScrapDetailObj,
  getScrapDetailObj,
  putScrapDetailObj
} from '../../../api/warehouse/scrapmain'
import { validateSixDecimalNegative } from '../../../util/validate'

export default {
  components: {
    Stock
  },
  data() {
    return {
      status: false,
      isDisable: false,
      showStock: false,
      visible: false,
      dataForm: {
        id: 0,
        scrapMainId: '',
        partId: '',
        partBatchNo: '',
        partSn: '',
        warehouseId: '',
        locationId: '',
        locQty: '',
        scrapQty: '',
        scrapUser: '',
        scrapTime: '',
        status: '',
        systemNo: ''
      },
      dataRule: {
        partId: [{ required: true, message: '零件不能为空', trigger: 'blur' }],
        scrapQty: [
          { required: true, message: '报废数量不能为空', trigger: 'blur' },
          { validator: validateSixDecimalNegative, trigger: 'blur' }
        ]
      }
    }
  },
  computed: {
    ...mapGetters(['permissions', 'userInfo']),
    editable: function() {
      if (!this.dataForm.id) {
        return true
      }
      if (this.dataForm.id && this.dataForm.status == '未下发') {
        return true
      }
      return false
    }
  },
  methods: {
    init(id, mainId, mainNo) {
      this.dataForm.id = id || 0
      this.visible = true
      this.dataForm.partNo = ''
      this.dataForm.warehouseName = ''
      this.dataForm.scrapMainId = ''
      this.dataForm.scrapMainId = mainId
      this.dataForm.scrapNo = mainNo
      this.dataForm.scrapUser = this.userInfo.username
      this.dataForm.status = '未下发'
      this.$nextTick(() => {
        this.$refs.dataForm.resetFields()
        if (this.dataForm.id) {
          getScrapDetailObj(this.dataForm.id).then((response) => {
            this.dataForm = response.data.data
          })
        }
      })
    },
    // 实时库存弹窗
    openStockDialog() {
      this.showStock = true
    },
    selectStock(stock) {
      if (stock) {
        this.dataForm.locationId = stock.locationId
        this.dataForm.locationName = stock.locationName
        this.dataForm.partId = stock.partId
        this.dataForm.partNo = stock.partNo
        this.dataForm.partBatchNo = stock.partBatchNo
        this.dataForm.systemNo = stock.systemNo
        this.dataForm.warehouseName = stock.warehouseName
        this.dataForm.locQty = stock.stockQuantity
        this.dataForm.warehouseId = stock.warehouseId
        this.$refs.dataForm.validateField('partId', (valid) => {})
      }
    },
    // 表单提交
    dataFormSubmit(status) {
      this.$refs.dataForm.validate((valid) => {
        if (valid) {
          if (this.dataForm.id) {
            putScrapDetailObj(this.dataForm).then((data) => {
              this.$message.success('修改成功')
              this.$emit('refreshDataList')
              this.visible = false
            })
          } else {
            addScrapDetailObj(this.dataForm).then((response) => {
              this.$message.success('添加成功')
              this.$emit('refreshDataList')
              this.visible = false
            })
          }
        }
      })
    }
  }
}
</script>
